@@ -59,8 +59,10 @@ def main() -> None:
     campaign.write_sell_policy()
 
     campaign.analyse_make_policy()
+    campaign.write_make_policy()
 
     reporting.have_in_bag()
+    reporting.make_missing()
 
     logger.info(f"Program end, seconds {(dt.now() - run_dt).total_seconds()}")
 
